summaryrefslogtreecommitdiff
path: root/engine/battle_anims/anim_commands.asm
diff options
context:
space:
mode:
Diffstat (limited to 'engine/battle_anims/anim_commands.asm')
-rw-r--r--engine/battle_anims/anim_commands.asm6
1 files changed, 3 insertions, 3 deletions
diff --git a/engine/battle_anims/anim_commands.asm b/engine/battle_anims/anim_commands.asm
index 113e9df37..bbfc1240e 100644
--- a/engine/battle_anims/anim_commands.asm
+++ b/engine/battle_anims/anim_commands.asm
@@ -237,14 +237,14 @@ BattleAnim_ClearOAM:
bit BATTLEANIM_KEEPSPRITES_F, a
jr z, .delete
; Instead of deleting the sprites, make them all use palette 0 (monochrome)
ld hl, wVirtualOAMSprite00Attributes
ld c, NUM_SPRITE_OAM_STRUCTS
.loop
ld a, [hl]
- and $ff ^ (PALETTE_MASK | VRAM_BANK_1)
+ and $ff ^ (PALETTE_MASK | VRAM_BANK_1) ; PAL_BATTLE_OB_ENEMY (0)
ld [hli], a
-rept SPRITEOAMSTRUCT_LENGTH + -1
+rept SPRITEOAMSTRUCT_LENGTH - 1
inc hl
endr
dec c
@@ -237,14 +237,14 @@ BattleAnim_ClearOAM:
bit BATTLEANIM_KEEPSPRITES_F, a
jr z, .delete
- ; Instead of deleting the sprites, make them all use palette 0 (monochrome)
+ ; Instead of deleting the sprites, make them all use PAL_BATTLE_OB_ENEMY
ld hl, wVirtualOAMSprite00Attributes
ld c, NUM_SPRITE_OAM_STRUCTS